@@ -48,3 +48,9 @@ def generate_random_string(with_letters: bool, with_numbers: bool, with_symbols:
 def hex_to_rgb(hex_color):
     hex_tuple = hex_color.lstrip('#')
     return tuple(int(hex_tuple[i:i + 2], 16) for i in (0, 2, 4))
+
+
+# will run a command in the command line
+def run_command(cmd):
+    import os
+    os.system(cmd)
